Release 29.0

This commit is contained in:
Neal Gompa 2022-04-24 10:50:40 -04:00
parent e98b433aa4
commit 0eba8e746c
5 changed files with 23 additions and 133 deletions

1
.gitignore vendored
View File

@ -22,3 +22,4 @@
/livecd-tools-28.1.tar.gz
/livecd-tools-28.2.tar.gz
/livecd-tools-28.3.tar.gz
/livecd-tools-29.0.tar.gz

View File

@ -1,29 +0,0 @@
From 3fe2b3927e21e8a81c53baae83243100acad3b0c Mon Sep 17 00:00:00 2001
From: Freeman Zhang <zhanggyb@lenovo.com>
Date: Thu, 25 Nov 2021 11:23:17 +0800
Subject: [PATCH] Copy 'unicode.pf2' from correct path
The 'unicode.pf2' font file for grub2 does not exist in
'/boot/efi/EFI/' any more in Fedora 35, and causes image build
fail. Use '/usr/share/grub/unicode.pf2' which belongs to
'grub2-tools' package instead.
---
imgcreate/live.py | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/imgcreate/live.py b/imgcreate/live.py
index e71cc49..8f971b6 100644
--- a/imgcreate/live.py
+++ b/imgcreate/live.py
@@ -720,7 +720,7 @@ menu end
("/boot/efi/EFI/*/gcd%s.efi" % (self.efiarch.lower(),), "/EFI/BOOT/grub%s.efi" % (self.efiarch.lower(),), True),
("/boot/efi/EFI/*/shimia32.efi", "/EFI/BOOT/BOOTIA32.EFI", False),
("/boot/efi/EFI/*/gcdia32.efi", "/EFI/BOOT/grubia32.efi", False),
- ("/boot/efi/EFI/*/fonts/unicode.pf2", "/EFI/BOOT/fonts/", True),
+ ("/usr/share/grub/unicode.pf2", "/EFI/BOOT/fonts/", True),
]
makedirs(isodir+"/EFI/BOOT/fonts/")
for src, dest, required in files:
--
2.33.1

View File

@ -1,98 +0,0 @@
From 9c7f40e7edae3475be9a0b8afd7b390a7ad3bfbc Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Pavel=20B=C5=99ezina?= <pbrezina@redhat.com>
Date: Mon, 12 Jul 2021 13:47:12 +0200
Subject: [PATCH] switch from authconfig to authselect
Authconfig compatibility tool (from authselect-compat) will be removed from Fedora 35:
https://fedoraproject.org/wiki/Changes/RemoveAuthselectCompatPackage
---
config/livecd-fedora-minimal.ks | 2 +-
config/livecd-mageia-minimal-i586.ks | 2 +-
config/livecd-mageia-minimal-x86_64.ks | 2 +-
imgcreate/creator.py | 2 +-
imgcreate/kickstart.py | 13 ++++++-------
5 files changed, 10 insertions(+), 11 deletions(-)
diff --git a/config/livecd-fedora-minimal.ks b/config/livecd-fedora-minimal.ks
index aeb1b046f0f602a07c3c4d0ee0685d460d4838ad..6aec2107041755291228178ec6ed5686f7fc5477 100644
--- a/config/livecd-fedora-minimal.ks
+++ b/config/livecd-fedora-minimal.ks
@@ -1,7 +1,7 @@
lang en_US.UTF-8
keyboard us
timezone US/Eastern
-auth --useshadow --passalgo=sha512
+authselect select sssd with-silent-lastlog --force
selinux --enforcing
firewall --disabled
part / --size 2048
diff --git a/config/livecd-mageia-minimal-i586.ks b/config/livecd-mageia-minimal-i586.ks
index 0b7e239977905d5c23c3ae05054fbe320eabbffb..12e6c65de7c1cf2d3e31f413abf4981a0dac7fe6 100644
--- a/config/livecd-mageia-minimal-i586.ks
+++ b/config/livecd-mageia-minimal-i586.ks
@@ -1,7 +1,7 @@
lang en_US.UTF-8
keyboard us
timezone US/Eastern
-auth --useshadow --passalgo=sha512
+authselect select sssd with-silent-lastlog --force
selinux --disabled
firewall --disabled
part / --size 1536
diff --git a/config/livecd-mageia-minimal-x86_64.ks b/config/livecd-mageia-minimal-x86_64.ks
index 19e6273e82efa41edd6fb72c32aa36fc51a8cbdb..defb9e036bc97182ff3617c4dfd51eea09cc92f9 100644
--- a/config/livecd-mageia-minimal-x86_64.ks
+++ b/config/livecd-mageia-minimal-x86_64.ks
@@ -1,7 +1,7 @@
lang en_US.UTF-8
keyboard us
timezone US/Eastern
-auth --useshadow --passalgo=sha512
+authselect select sssd with-silent-lastlog --force
selinux --disabled
firewall --disabled
part / --size 1536
diff --git a/imgcreate/creator.py b/imgcreate/creator.py
index 692d2873bd51e61ff4945ac9d7e980a3255a399e..654edcb5ec7c19360e5ba9fbd1cd0a780b2f9a1d 100644
--- a/imgcreate/creator.py
+++ b/imgcreate/creator.py
@@ -788,7 +788,7 @@ class ImageCreator(object):
kickstart.LanguageConfig(self._instroot).apply(ksh.lang)
kickstart.KeyboardConfig(self._instroot).apply(ksh.keyboard)
kickstart.TimezoneConfig(self._instroot).apply(ksh.timezone)
- kickstart.AuthConfig(self._instroot).apply(ksh.authconfig)
+ kickstart.AuthSelect(self._instroot).apply(ksh.authselect)
kickstart.FirewallConfig(self._instroot).apply(ksh.firewall)
kickstart.RootPasswordConfig(self._instroot).apply(ksh.rootpw)
kickstart.ServicesConfig(self._instroot).apply(ksh.services)
diff --git a/imgcreate/kickstart.py b/imgcreate/kickstart.py
index 526a2028d2a9b32fa6b02dc32af8f4912919ea2f..afb8bfefb4bd9c20a2f45788fc2f0dccd4842c38 100644
--- a/imgcreate/kickstart.py
+++ b/imgcreate/kickstart.py
@@ -179,17 +179,16 @@ class TimezoneConfig(KickstartConfig):
os.unlink(localtime)
os.symlink("/usr/share/zoneinfo/%s" %(tz,), localtime)
-class AuthConfig(KickstartConfig):
- """A class to apply a kickstart authconfig configuration to a system."""
- def apply(self, ksauthconfig):
+class AuthSelect(KickstartConfig):
+ """A class to apply a kickstart authselect configuration to a system."""
+ def apply(self, ksauthselect):
- auth = ksauthconfig.authconfig or "--useshadow --enablemd5"
- args = ["authconfig", "--update", "--nostart"]
+ auth = ksauthselect.authselect or "select sssd with-silent-lastlog --force"
try:
- subprocess.call(args + auth.split(), preexec_fn=self.chroot)
+ subprocess.call(['authselect'] + auth.split(), preexec_fn=self.chroot)
except OSError as e:
if e.errno == errno.ENOENT:
- logging.info('The authconfig command is not available.')
+ logging.info('The authselect command is not available.')
return
class FirewallConfig(KickstartConfig):
--
2.31.1

View File

@ -16,8 +16,8 @@
Summary: Tools for building live CDs
Name: livecd-tools
Version: 28.3
Release: 5%{?dist}
Version: 29.0
Release: 1%{?dist}
%if 0%{?fedora}
Epoch: 1
%endif
@ -25,9 +25,6 @@ License: GPLv2
URL: https://github.com/livecd-tools/livecd-tools
Source0: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz
Patch1: 0001-switch-from-authconfig-to-authselect.patch
Patch2: 0001-Copy-unicode.pf2-from-correct-path.patch
BuildRequires: make
%if %{with python2}
BuildRequires: python2-devel
@ -228,6 +225,25 @@ rm -rfv %{buildroot}%{_mandir}/man8/livecd-iso-to-*
%endif
%changelog
* Sun Apr 24 2022 Neal Gompa <ngompa@fedoraproject.org> - 1:29.0-1
- Release 29.0 (ngompa13)
- Makefile: Drop creating signed tags (ngompa13)
- Preload the libnss_systemd library (#2007045) (sergey)
- livecd-iso-to-disk, editliveos: Add option to skip macboot.img processing.
(fgrose)
- Copy 'unicode.pf2' from correct path (zhanggyb)
- editliveos: Refresh vmlinuz & initrd.img files upon kernel updates. (fgrose)
- livecd-iso-to-disk & editliveos: Preserve extra-kernel-args from source.
(fgrose)
- add livenet dracut module to allow for pxe boot (sobjerke)
- switch from authconfig to authselect (pbrezina)
- live.py: Support either /images or /isolinux directories for efi images.
(fgrose)
- livecd-iso-to-disk & editliveos: Expand partitioning & filesystem support
(fgrose)
- make live image the default boot option (sobjerke)
- Modernize detection of checkisomd5 (m.novosyolov)
* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:28.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

View File

@ -1 +1 @@
SHA512 (livecd-tools-28.3.tar.gz) = a1bfd0c4536243f0c3970d9af22c5d73d56822ab0cdbb3aefb821b1e6073ebd560651e715fec70a0ba8d864af828cbc60900f6f2a910aa53be6a23dc3b3d5ec7
SHA512 (livecd-tools-29.0.tar.gz) = ac9f7326d015b6d0448545339bbaecaf6ca6595f51b2bd6bf29da5d0a138154e481ca97f5b419c8d5fa49ece0ce8d3bb0bacbccb3bfcec3655b7a86172d5ea0f